#charset "us-ascii"

/* 
 *   Copyright (c) 2000, 2002 Michael J. Roberts
 *   
 *   This file is part of TADS 3.  
 */

#ifndef _DICT_H_
#define _DICT_H_

/*
 *   'dictionary' metaclass 
 */
intrinsic class Dictionary 'dictionary/030001'
{
    /* 
     *   Find a word; returns a list giving the objects associated with the
     *   string in the dictionary.  If voc_prop is specified, only objects
     *   associated with the word by the given vocabulary property are
     *   returned.  
     */
    findWord(str, voc_prop?);

    /*
     *   Find a word with truncation.  Returns a list giving the object
     *   associated with the string in the dictionary.  If the string is at
     *   least as long as the current truncation length (as set with
     *   setTruncLen()), returns all objects associated with strings of
     *   which the given string is a leading substring; for example, if the
     *   string is "flashl", we would include in the returned list an object
     *   associated with "flashlight".
     *   
     *   If the given string is shorter than the current truncation length,
     *   only exact matches are returned.  
     */
    findWordTrunc(str, voc_prop?);

    /*
     *   Set the truncation length for the dictionary.  This establishes the
     *   minimum length for truncated matches in findWordTrunc().  
     */
    setTruncLen(len);

    /*
     *   Add a word to the dictionary, associating the given object with the
     *   given string and property combination. 
     */
    addWord(obj, str, voc_prop);

    /*
     *   Remove the given word association from the dictionary.  This
     *   removes only the association for the given object; other objects
     *   associated with the same word are not affected.  
     */
    removeWord(obj, str, voc_prop);

    /* check to see if the given string is defined in the dictionary */
    isWordDefined(str);

    /* 
     *   check to see if the given string is a truncated match for any word
     *   in the dictionary, using the current truncation length set with
     *   setTruncLen() 
     */
    isWordDefinedTrunc(str);

    /*
     *   Invoke the callback func(str, obj, prop) for each word in the
     *   dictionary.  Note that the callback can be invoked with a single
     *   string multiple times, since the callback is invoked once per
     *   word/object/property association; in other words, the callback is
     *   invoked once for each association created with addWord() or during
     *   compilation.  
     */
    forEachWord(func);
}

#endif /* _DICT_H_ */
