#charset "us-ascii"

/* 
 *   Copyright (c) 1999, 2002 Michael J. Roberts
 *   
 *   This file is part of TADS 3 
 */

/*
 *   TADS Input/Output intrinsic function set 
 */

#ifndef TADSIO_H
#define TADSIO_H

/*
 *   the TADS input/output function set 
 */
intrinsic 'tads-io/030004'
{
    /* display values on the console */
    tadsSay(val, ...);

    /* set the display capture log file */
    setLogFile(fname);

    /* clear the display */
    clearScreen();

    /* show the "more" prompt, if supported on the platform */
    morePrompt();

    /* read a line of text from the keyboard */
    inputLine();

    /* read a single keystroke from the keyboard */
    inputKey();

    /* read a single input event */
    inputEvent(timeout?);

    /* display a simple dialog */
    inputDialog(icon, prompt, buttons, defaultButton, cancelButton);

    /* display a file selector dialog */
    inputFile(prompt, dialogType, fileType, flags);

    /* pause */
    timeDelay(delayMilliseconds);

    /* retrieve local system information */
    systemInfo(infoType, ...);

    /* set the status-line display mode, for text-only interpreters */
    statusMode(mode);

    /* write text on the right half of the status, for text-only terps */
    statusRight(txt);

    /* determine if a multimedia resource exists */
    resExists(fname);

    /* set the script input file */
    setScriptFile(filename, flags?);

    /* get the local default character set */
    getLocalCharSet(which);

    /* flush text output and update the display */
    flushOutput();

    /* read a line of text from the keyboard with an optional timeout */
    inputLineTimeout(timeout?);

    /* cancel an input line that was interrupted by timeout */
    inputLineCancel(reset);
}

/* 
 *   constants for the event codes returned by the inputEvent() and
 *   inputLineTimeout() intrinsic functions 
 */
#define InEvtKey        1
#define InEvtTimeout    2
#define InEvtHref       3
#define InEvtNotimeout  4
#define InEvtEof        5
#define InEvtLine       6
#define InEvtEndQuietScript  10000

/*
 *   constants for inputDialog() 
 */
#define InDlgOk               1
#define InDlgOkCancel         2
#define InDlgYesNo            3
#define InDlgYesNoCancel      4

#define InDlgIconNone        0
#define InDlgIconWarning     1
#define InDlgIconInfo        2
#define InDlgIconQuestion    3
#define InDlgIconError       4

#define InDlgLblOk           1
#define InDlgLblCancel       2
#define InDlgLblYes          3
#define InDlgLblNo           4

/*
 *   inputFile() dialog types 
 */
#define InFileOpen    1                /* open an existing file for reading */
#define InFileSave    2                                 /* save to the file */

/*
 *   inputFile() return codes - these are returned in the first element of
 *   the list returned from askfile() 
 */
#define InFileSuccess        0    /* success - 2nd list element is filename */
#define InFileFailure        1       /* an error occurred asking for a file */
#define InFileCancel         2         /* player canceled the file selector */

/*
 *   constants for inputFile() file type codes 
 */
#define FileTypeLog     2                        /* a transcript (log) file */
#define FileTypeData    4           /* general data file (used for fopen()) */
#define FileTypeCmd     5                             /* command input file */
#define FileTypeText    7                                      /* text file */
#define FileTypeBin     8                               /* binary data file */
#define FileTypeUnknown 11                             /* unknown file type */
#define FileTypeT3Image 12               /* T3 executable image (game) file */
#define FileTypeT3Save  15                           /* T3 saved state file */

/*
 *   constants for systemInfo information type codes 
 */
#define SysInfoVersion       2
#define SysInfoOsName        3
#define SysInfoHtml          4
#define SysInfoJpeg          5
#define SysInfoPng           6
#define SysInfoWav           7
#define SysInfoMidi          8
#define SysInfoWavMidiOvl    9
#define SysInfoWavOvl        10
#define SysInfoPrefImages    11
#define SysInfoPrefSounds    12
#define SysInfoPrefMusic     13
#define SysInfoPrefLinks     14
#define SysInfoMpeg          15
#define SysInfoMpeg1         16
#define SysInfoMpeg2         17
#define SysInfoMpeg3         18
#define SysInfoHtmlMode      19
#define SysInfoLinksHttp     20
#define SysInfoLinksFtp      21
#define SysInfoLinksNews     22
#define SysInfoLinksMailto   23
#define SysInfoLinksTelnet   24
#define SysInfoPngTrans      25
#define SysInfoPngAlpha      26
#define SysInfoOgg           27
#define SysInfoMng           28
#define SysInfoMngTrans      29
#define SysInfoMngAlpha      30
#define SysInfoTextHilite    31
#define SysInfoTextColors    32

/* SysInfoTextColors support level codes */
#define SysInfoTxcNone       0
#define SysInfoTxcParam      1
#define SysInfoTxcAnsiFg     2
#define SysInfoTxcAnsiFgBg   3
#define SysInfoTxcRGB        4

/*
 *   constants for statusMode 
 */
#define StatModeNormal    0                       /* displaying normal text */
#define StatModeStatus    1                     /* display status line text */

/*
 *   flags for setScriptFile 
 */
#define ScriptFileQuiet    1  /* do not display output while reading script */
#define ScriptFileNonstop  2   /* turn off MORE prompt while reading script */

/*
 *   selectors for getLocalCharSet
 */
#define CharsetDisplay  1             /* the display/keyboard character set */
#define CharsetFile     2                  /* the file system character set */


#endif /* TADSIO_H */
